@@ -51,8 +51,8 @@ use Win32::TieRegistry;
 # create the WxApplication
 my $app = Wx::SimpleApp->new;
 my $frame = Wx::Frame->new(undef, -1,
-		           'FullAuto Automates EVERYTHING Demonstration',
-                           wxDefaultPosition,[ 800, 600 ]);
+	        ' FullAuto Automates EVERYTHING - AWS Installer Dashboard',
+                 wxDefaultPosition,[ 800, 600 ]);
 SplitterWindow($frame);
 $frame->Show;
 $app->MainLoop;
@@ -475,8 +475,9 @@ sub evt_process_exit {
       copy "cmds_saved.template", "cmds.txt";
       my $iptext=$self->{ip_txt};
       $set_shifted_flag=1;
+print "WHAT IS THISSSSS=$self->{ppk_file}\n";
       my $proc=Wx::Perl::ProcessStream::Process->new(
-            "runputty $self->{ppk_file} $iptext",'putty',$self);
+            "runputty \'$self->{ppk_file}\' $iptext",'putty',$self);
       $self->{shifted_cmds}=$proc;
       $proc->Run;
     } elsif (!exists $self->{webapp}) {
@@ -555,7 +556,7 @@ sub fullauto_button {
    EVT_WXP_PROCESS_STREAM_EXIT($self, \&evt_process_exit);
    unless ((-e "saved.txt") || (-e "ip.txt")) {
       unless (-e "$keybasename.ppk") {
-         Wx::ExecuteCommand("puttykey $keybasename $path",wxEXEC_SYNC);
+         Wx::ExecuteCommand("puttykey \"$keybasename\" $path",wxEXEC_SYNC);
       }
       if (exists $ENV{PAR_TEMP} && (-e "$ENV{PAR_TEMP}/inc")) {
          copy "$path/$keybasename.ppk", "$ENV{PAR_TEMP}/inc";
@@ -565,7 +566,7 @@ sub fullauto_button {
       unlink "$path/$keybasename.ppk";
       my ($rcode,$stdout,$stderr)=('','','');
       ($rcode,$stdout,$stderr)=Wx::ExecuteStdoutStderr(
-         "puttyyes $keybasename.ppk ec2-user $i",
+         "puttyyes \"$keybasename.ppk\" ec2-user $i",
          wxEXEC_SYNC);
       if ($rcode) {
          my $title="FullAuto Demo Fatal Error";
@@ -577,13 +578,13 @@ sub fullauto_button {
          return;
       }
       $self->{ppk_file}="$keybasename.ppk";
-      my $c="pscp.exe -batch -v -i $keybasename.ppk ".
+      my $c="pscp.exe -batch -v -i \"$keybasename.ppk\" ".
             "MyConfig.pm ec2-user\@$i:/home/ec2-user";
       Wx::Shell($c);
-      $c="pscp.exe -batch -v -i $keybasename.ppk ".
-            "$keybasename.pem ec2-user\@$i:/home/ec2-user";
+      $c="pscp.exe -batch -v -i \"$keybasename.ppk\" ".
+            "\"$keybasename.pem\" ec2-user\@$i:/home/ec2-user";
       Wx::Shell($c);
-      $c="pscp.exe -batch -v -i $keybasename.ppk ".
+      $c="pscp.exe -batch -v -i \"$keybasename.ppk\" ".
             "credentials.csv ec2-user\@$i:/home/ec2-user";
       Wx::Shell($c);
       copy "cmds.template", "cmds.txt";
@@ -612,7 +613,7 @@ sub fullauto_button {
    close FH;
 print "GOING TO RUNPUTTY\n";
    my $proc1=Wx::Perl::ProcessStream::Process->new(
-         "runputty $self->{ppk_file} $iptext",'putty',$self);
+         "runputty \"$self->{ppk_file}\" $iptext",'putty',$self);
    $proc1->Run;
 
 }
@@ -1055,7 +1056,7 @@ sub on_close {
             my $ping=Wx::ExecuteStdout("tcping $i 22",wxEXEC_SYNC);
             $ping=join '',@{$ping};
             if ((-1<index $ping,'Port is open') && $ppk_file) {
-               my $cmd="runcleanup $ppk_file $i";
+               my $cmd="runcleanup \"$ppk_file\" $i";
                Wx::ExecuteCommand($cmd,wxEXEC_SYNC)
             }
          }
